![Pyrinium](https://i.supa.codes/oiHZ49)
## Installation
`pip install pyrinium`
## Usage
TBA
## How it works
Module emulates user interactions with schedule. Written using reverse engineering tricks.
## License
MIT Licensed